# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetRuleSetResult',
    'AwaitableGetRuleSetResult',
    'get_rule_set',
    'get_rule_set_output',
]

@pulumi.output_type
class GetRuleSetResult:
    """
    A collection of values returned by getRuleSet.
    """
    def __init__(__self__, cloud_provider=None, description=None, id=None, name=None, rule_ids=None, rule_set_id=None):
        if cloud_provider and not isinstance(cloud_provider, str):
            raise TypeError("Expected argument 'cloud_provider' to be a str")
        pulumi.set(__self__, "cloud_provider", cloud_provider)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if rule_ids and not isinstance(rule_ids, list):
            raise TypeError("Expected argument 'rule_ids' to be a list")
        pulumi.set(__self__, "rule_ids", rule_ids)
        if rule_set_id and not isinstance(rule_set_id, str):
            raise TypeError("Expected argument 'rule_set_id' to be a str")
        pulumi.set(__self__, "rule_set_id", rule_set_id)

    @_builtins.property
    @pulumi.getter(name="cloudProvider")
    def cloud_provider(self) -> _builtins.str:
        """
        The cloud provider for the rule set.
        """
        return pulumi.get(self, "cloud_provider")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description for rule set.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the rule set.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="ruleIds")
    def rule_ids(self) -> Sequence[_builtins.str]:
        """
        List of target regions.
        """
        return pulumi.get(self, "rule_ids")

    @_builtins.property
    @pulumi.getter(name="ruleSetId")
    def rule_set_id(self) -> _builtins.str:
        """
        Id of rule set.
        """
        return pulumi.get(self, "rule_set_id")


class AwaitableGetRuleSetResult(GetRuleSetResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRuleSetResult(
            cloud_provider=self.cloud_provider,
            description=self.description,
            id=self.id,
            name=self.name,
            rule_ids=self.rule_ids,
            rule_set_id=self.rule_set_id)


def get_rule_set(rule_set_id: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRuleSetResult:
    """
    Datasource for looking up a rule.


    :param _builtins.str rule_set_id: Id of rule set.
    """
    __args__ = dict()
    __args__['ruleSetId'] = rule_set_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:governance/getRuleSet:getRuleSet', __args__, opts=opts, typ=GetRuleSetResult).value

    return AwaitableGetRuleSetResult(
        cloud_provider=pulumi.get(__ret__, 'cloud_provider'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        rule_ids=pulumi.get(__ret__, 'rule_ids'),
        rule_set_id=pulumi.get(__ret__, 'rule_set_id'))
def get_rule_set_output(rule_set_id: Optional[pulumi.Input[_builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRuleSetResult]:
    """
    Datasource for looking up a rule.


    :param _builtins.str rule_set_id: Id of rule set.
    """
    __args__ = dict()
    __args__['ruleSetId'] = rule_set_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:governance/getRuleSet:getRuleSet', __args__, opts=opts, typ=GetRuleSetResult)
    return __ret__.apply(lambda __response__: GetRuleSetResult(
        cloud_provider=pulumi.get(__response__, 'cloud_provider'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        rule_ids=pulumi.get(__response__, 'rule_ids'),
        rule_set_id=pulumi.get(__response__, 'rule_set_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .add_user_to_group import *
from .application import *
from .application_git_sync import *
from .chaos_infrastructure import *
from .delegate_approval import *
from .encrypted_text import *
from .environment import *
from .get_application import *
from .get_chaos_infrastructure import *
from .get_current_account import *
from .get_delegate import *
from .get_encrypted_text import *
from .get_environment import *
from .get_git_connector import *
from .get_secret_manager import *
from .get_service import *
from .get_ssh_credential import *
from .get_sso_provider import *
from .get_trigger import *
from .get_user import *
from .get_user_group import *
from .get_yaml_config import *
from .git_connector import *
from .infrastructure_definition import *
from .platform_api_key import *
from .platform_ccm_filters import *
from .provider import *
from .ssh_credential import *
from .user import *
from .user_group import *
from .user_group_permissions import *
from .yaml_config import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_harness.autostopping as __autostopping
    autostopping = __autostopping
    import pulumi_harness.chaos as __chaos
    chaos = __chaos
    import pulumi_harness.cloudprovider as __cloudprovider
    cloudprovider = __cloudprovider
    import pulumi_harness.cluster as __cluster
    cluster = __cluster
    import pulumi_harness.config as __config
    config = __config
    import pulumi_harness.governance as __governance
    governance = __governance
    import pulumi_harness.platform as __platform
    platform = __platform
    import pulumi_harness.service as __service
    service = __service
else:
    autostopping = _utilities.lazy_import('pulumi_harness.autostopping')
    chaos = _utilities.lazy_import('pulumi_harness.chaos')
    cloudprovider = _utilities.lazy_import('pulumi_harness.cloudprovider')
    cluster = _utilities.lazy_import('pulumi_harness.cluster')
    config = _utilities.lazy_import('pulumi_harness.config')
    governance = _utilities.lazy_import('pulumi_harness.governance')
    platform = _utilities.lazy_import('pulumi_harness.platform')
    service = _utilities.lazy_import('pulumi_harness.service')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "harness",
  "mod": "autostopping/awsAlb",
  "fqn": "pulumi_harness.autostopping",
  "classes": {
   "harness:autostopping/awsAlb:AwsAlb": "AwsAlb"
  }
 },
 {
  "pkg": "harness",
  "mod": "autostopping/awsProxy",
  "fqn": "pulumi_harness.autostopping",
  "classes": {
   "harness:autostopping/awsProxy:AwsProxy": "AwsProxy"
  }
 },
 {
  "pkg": "harness",
  "mod": "autostopping/azureGateway",
  "fqn": "pulumi_harness.autostopping",
  "classes": {
   "harness:autostopping/azureGateway:AzureGateway": "AzureGateway"
  }
 },
 {
  "pkg": "harness",
  "mod": "autostopping/azureProxy",
  "fqn": "pulumi_harness.autostopping",
  "classes": {
   "harness:autostopping/azureProxy:AzureProxy": "AzureProxy"
  }
 },
 {
  "pkg": "harness",
  "mod": "autostopping/gcpProxy",
  "fqn": "pulumi_harness.autostopping",
  "classes": {
   "harness:autostopping/gcpProxy:GcpProxy": "GcpProxy"
  }
 },
 {
  "pkg": "harness",
  "mod": "autostopping/ruleEcs",
  "fqn": "pulumi_harness.autostopping",
  "classes": {
   "harness:autostopping/ruleEcs:RuleEcs": "RuleEcs"
  }
 },
 {
  "pkg": "harness",
  "mod": "autostopping/ruleRds",
  "fqn": "pulumi_harness.autostopping",
  "classes": {
   "harness:autostopping/ruleRds:RuleRds": "RuleRds"
  }
 },
 {
  "pkg": "harness",
  "mod": "autostopping/ruleScaleGroup",
  "fqn": "pulumi_harness.autostopping",
  "classes": {
   "harness:autostopping/ruleScaleGroup:RuleScaleGroup": "RuleScaleGroup"
  }
 },
 {
  "pkg": "harness",
  "mod": "autostopping/ruleVm",
  "fqn": "pulumi_harness.autostopping",
  "classes": {
   "harness:autostopping/ruleVm:RuleVm": "RuleVm"
  }
 },
 {
  "pkg": "harness",
  "mod": "autostopping/schedule",
  "fqn": "pulumi_harness.autostopping",
  "classes": {
   "harness:autostopping/schedule:Schedule": "Schedule"
  }
 },
 {
  "pkg": "harness",
  "mod": "chaos/hub",
  "fqn": "pulumi_harness.chaos",
  "classes": {
   "harness:chaos/hub:Hub": "Hub"
  }
 },
 {
  "pkg": "harness",
  "mod": "chaos/hubSync",
  "fqn": "pulumi_harness.chaos",
  "classes": {
   "harness:chaos/hubSync:HubSync": "HubSync"
  }
 },
 {
  "pkg": "harness",
  "mod": "chaos/imageRegistry",
  "fqn": "pulumi_harness.chaos",
  "classes": {
   "harness:chaos/imageRegistry:ImageRegistry": "ImageRegistry"
  }
 },
 {
  "pkg": "harness",
  "mod": "chaos/infrastructureV2",
  "fqn": "pulumi_harness.chaos",
  "classes": {
   "harness:chaos/infrastructureV2:InfrastructureV2": "InfrastructureV2"
  }
 },
 {
  "pkg": "harness",
  "mod": "chaos/securityGovernanceCondition",
  "fqn": "pulumi_harness.chaos",
  "classes": {
   "harness:chaos/securityGovernanceCondition:SecurityGovernanceCondition": "SecurityGovernanceCondition"
  }
 },
 {
  "pkg": "harness",
  "mod": "chaos/securityGovernanceRule",
  "fqn": "pulumi_harness.chaos",
  "classes": {
   "harness:chaos/securityGovernanceRule:SecurityGovernanceRule": "SecurityGovernanceRule"
  }
 },
 {
  "pkg": "harness",
  "mod": "cloudprovider/aws",
  "fqn": "pulumi_harness.cloudprovider",
  "classes": {
   "harness:cloudprovider/aws:Aws": "Aws"
  }
 },
 {
  "pkg": "harness",
  "mod": "cloudprovider/azure",
  "fqn": "pulumi_harness.cloudprovider",
  "classes": {
   "harness:cloudprovider/azure:Azure": "Azure"
  }
 },
 {
  "pkg": "harness",
  "mod": "cloudprovider/datacenter",
  "fqn": "pulumi_harness.cloudprovider",
  "classes": {
   "harness:cloudprovider/datacenter:Datacenter": "Datacenter"
  }
 },
 {
  "pkg": "harness",
  "mod": "cloudprovider/gcp",
  "fqn": "pulumi_harness.cloudprovider",
  "classes": {
   "harness:cloudprovider/gcp:Gcp": "Gcp"
  }
 },
 {
  "pkg": "harness",
  "mod": "cloudprovider/kubernetes",
  "fqn": "pulumi_harness.cloudprovider",
  "classes": {
   "harness:cloudprovider/kubernetes:Kubernetes": "Kubernetes"
  }
 },
 {
  "pkg": "harness",
  "mod": "cloudprovider/spot",
  "fqn": "pulumi_harness.cloudprovider",
  "classes": {
   "harness:cloudprovider/spot:Spot": "Spot"
  }
 },
 {
  "pkg": "harness",
  "mod": "cloudprovider/tanzu",
  "fqn": "pulumi_harness.cloudprovider",
  "classes": {
   "harness:cloudprovider/tanzu:Tanzu": "Tanzu"
  }
 },
 {
  "pkg": "harness",
  "mod": "cluster/orchestrator",
  "fqn": "pulumi_harness.cluster",
  "classes": {
   "harness:cluster/orchestrator:Orchestrator": "Orchestrator"
  }
 },
 {
  "pkg": "harness",
  "mod": "cluster/orchestratorConfig",
  "fqn": "pulumi_harness.cluster",
  "classes": {
   "harness:cluster/orchestratorConfig:OrchestratorConfig": "OrchestratorConfig"
  }
 },
 {
  "pkg": "harness",
  "mod": "governance/rule",
  "fqn": "pulumi_harness.governance",
  "classes": {
   "harness:governance/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "harness",
  "mod": "governance/ruleEnforcement",
  "fqn": "pulumi_harness.governance",
  "classes": {
   "harness:governance/ruleEnforcement:RuleEnforcement": "RuleEnforcement"
  }
 },
 {
  "pkg": "harness",
  "mod": "governance/ruleSet",
  "fqn": "pulumi_harness.governance",
  "classes": {
   "harness:governance/ruleSet:RuleSet": "RuleSet"
  }
 },
 {
  "pkg": "harness",
  "mod": "index/addUserToGroup",
  "fqn": "pulumi_harness",
  "classes": {
   "harness:index/addUserToGroup:AddUserToGroup": "AddUserToGroup"
  }
 },
 {
  "pkg": "harness",
  "mod": "index/application",
  "fqn": "pulumi_harness",
  "classes": {
   "harness:index/application:Application": "Application"
  }
 },
 {
  "pkg": "harness",
  "mod": "index/applicationGitSync",
  "fqn": "pulumi_harness",
  "classes": {
   "harness:index/applicationGitSync:ApplicationGitSync": "ApplicationGitSync"
  }
 },
 {
  "pkg": "harness",
  "mod": "index/chaosInfrastructure",
  "fqn": "pulumi_harness",
  "classes": {
   "harness:index/chaosInfrastructure:ChaosInfrastructure": "ChaosInfrastructure"
  }
 },
 {
  "pkg": "harness",
  "mod": "index/delegateApproval",
  "fqn": "pulumi_harness",
  "classes": {
   "harness:index/delegateApproval:DelegateApproval": "DelegateApproval"
  }
 },
 {
  "pkg": "harness",
  "mod": "index/encryptedText",
  "fqn": "pulumi_harness",
  "classes": {
   "harness:index/encryptedText:EncryptedText": "EncryptedText"
  }
 },
 {
  "pkg": "harness",
  "mod": "index/environment",
  "fqn": "pulumi_harness",
  "classes": {
   "harness:index/environment:Environment": "Environment"
  }
 },
 {
  "pkg": "harness",
  "mod": "index/gitConnector",
  "fqn": "pulumi_harness",
  "classes": {
   "harness:index/gitConnector:GitConnector": "GitConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "index/infrastructureDefinition",
  "fqn": "pulumi_harness",
  "classes": {
   "harness:index/infrastructureDefinition:InfrastructureDefinition": "InfrastructureDefinition"
  }
 },
 {
  "pkg": "harness",
  "mod": "index/platformApiKey",
  "fqn": "pulumi_harness",
  "classes": {
   "harness:index/platformApiKey:PlatformApiKey": "PlatformApiKey"
  }
 },
 {
  "pkg": "harness",
  "mod": "index/platformCcmFilters",
  "fqn": "pulumi_harness",
  "classes": {
   "harness:index/platformCcmFilters:PlatformCcmFilters": "PlatformCcmFilters"
  }
 },
 {
  "pkg": "harness",
  "mod": "index/sshCredential",
  "fqn": "pulumi_harness",
  "classes": {
   "harness:index/sshCredential:SshCredential": "SshCredential"
  }
 },
 {
  "pkg": "harness",
  "mod": "index/user",
  "fqn": "pulumi_harness",
  "classes": {
   "harness:index/user:User": "User"
  }
 },
 {
  "pkg": "harness",
  "mod": "index/userGroup",
  "fqn": "pulumi_harness",
  "classes": {
   "harness:index/userGroup:UserGroup": "UserGroup"
  }
 },
 {
  "pkg": "harness",
  "mod": "index/userGroupPermissions",
  "fqn": "pulumi_harness",
  "classes": {
   "harness:index/userGroupPermissions:UserGroupPermissions": "UserGroupPermissions"
  }
 },
 {
  "pkg": "harness",
  "mod": "index/yamlConfig",
  "fqn": "pulumi_harness",
  "classes": {
   "harness:index/yamlConfig:YamlConfig": "YamlConfig"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/appDynamicsConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/appDynamicsConnector:AppDynamicsConnector": "AppDynamicsConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/artifactoryConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/artifactoryConnector:ArtifactoryConnector": "ArtifactoryConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/awsCCConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/awsCCConnector:AwsCCConnector": "AwsCCConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/awsConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/awsConnector:AwsConnector": "AwsConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/awsKmsConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/awsKmsConnector:AwsKmsConnector": "AwsKmsConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/awsSecretManagerConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/awsSecretManagerConnector:AwsSecretManagerConnector": "AwsSecretManagerConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/azureCloudCostConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/azureCloudCostConnector:AzureCloudCostConnector": "AzureCloudCostConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/azureCloudProviderConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/azureCloudProviderConnector:AzureCloudProviderConnector": "AzureCloudProviderConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/azureKeyVaultConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/azureKeyVaultConnector:AzureKeyVaultConnector": "AzureKeyVaultConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/bitbucketConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/bitbucketConnector:BitbucketConnector": "BitbucketConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/centralNotificationChannel",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/centralNotificationChannel:CentralNotificationChannel": "CentralNotificationChannel"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/centralNotificationRule",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/centralNotificationRule:CentralNotificationRule": "CentralNotificationRule"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/connectorAzureArtifacts",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/connectorAzureArtifacts:ConnectorAzureArtifacts": "ConnectorAzureArtifacts"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/connectorAzureRepo",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/connectorAzureRepo:ConnectorAzureRepo": "ConnectorAzureRepo"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/connectorCustomSecretManager",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/connectorCustomSecretManager:ConnectorCustomSecretManager": "ConnectorCustomSecretManager"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/connectorCustomhealthsource",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/connectorCustomhealthsource:ConnectorCustomhealthsource": "ConnectorCustomhealthsource"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/connectorGcpKms",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/connectorGcpKms:ConnectorGcpKms": "ConnectorGcpKms"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/connectorJdbc",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/connectorJdbc:ConnectorJdbc": "ConnectorJdbc"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/connectorPdc",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/connectorPdc:ConnectorPdc": "ConnectorPdc"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/connectorRancher",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/connectorRancher:ConnectorRancher": "ConnectorRancher"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/dashboardFolders",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/dashboardFolders:DashboardFolders": "DashboardFolders"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/dashboards",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/dashboards:Dashboards": "Dashboards"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/datadogConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/datadogConnector:DatadogConnector": "DatadogConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/dbInstance",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/dbInstance:DbInstance": "DbInstance"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/dbSchema",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/dbSchema:DbSchema": "DbSchema"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/defaultNotificationTemplateSet",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/defaultNotificationTemplateSet:DefaultNotificationTemplateSet": "DefaultNotificationTemplateSet"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/delegatetoken",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/delegatetoken:Delegatetoken": "Delegatetoken"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/dockerConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/dockerConnector:DockerConnector": "DockerConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/dynatraceConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/dynatraceConnector:DynatraceConnector": "DynatraceConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/elasticsearchConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/elasticsearchConnector:ElasticsearchConnector": "ElasticsearchConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/environment",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/environment:Environment": "Environment"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/environmentClustersMapping",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/environmentClustersMapping:EnvironmentClustersMapping": "EnvironmentClustersMapping"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/environmentGroup",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/environmentGroup:EnvironmentGroup": "EnvironmentGroup"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/environmentServiceOverrides",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/environmentServiceOverrides:EnvironmentServiceOverrides": "EnvironmentServiceOverrides"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/featureFlag",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/featureFlag:FeatureFlag": "FeatureFlag"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/featureFlagApiKey",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/featureFlagApiKey:FeatureFlagApiKey": "FeatureFlagApiKey"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/featureFlagTarget",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/featureFlagTarget:FeatureFlagTarget": "FeatureFlagTarget"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/featureFlagTargetGroup",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/featureFlagTargetGroup:FeatureFlagTargetGroup": "FeatureFlagTargetGroup"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/fileStoreFile",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/fileStoreFile:FileStoreFile": "FileStoreFile"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/fileStoreFolder",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/fileStoreFolder:FileStoreFolder": "FileStoreFolder"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/filters",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/filters:Filters": "Filters"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/gcpCloudCostConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/gcpCloudCostConnector:GcpCloudCostConnector": "GcpCloudCostConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/gcpConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/gcpConnector:GcpConnector": "GcpConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/gcpSecretManagerConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/gcpSecretManagerConnector:GcpSecretManagerConnector": "GcpSecretManagerConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/gitConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/gitConnector:GitConnector": "GitConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/gitOpsAgent",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/gitOpsAgent:GitOpsAgent": "GitOpsAgent"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/gitOpsApplications",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/gitOpsApplications:GitOpsApplications": "GitOpsApplications"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/gitOpsCluster",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/gitOpsCluster:GitOpsCluster": "GitOpsCluster"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/gitOpsGnupg",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/gitOpsGnupg:GitOpsGnupg": "GitOpsGnupg"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/gitOpsRepoCert",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/gitOpsRepoCert:GitOpsRepoCert": "GitOpsRepoCert"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/gitOpsRepoCred",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/gitOpsRepoCred:GitOpsRepoCred": "GitOpsRepoCred"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/gitOpsRepository",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/gitOpsRepository:GitOpsRepository": "GitOpsRepository"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/githubConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/githubConnector:GithubConnector": "GithubConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/gitlabConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/gitlabConnector:GitlabConnector": "GitlabConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/gitopsAppProject",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/gitopsAppProject:GitopsAppProject": "GitopsAppProject"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/gitopsAppProjectMapping",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/gitopsAppProjectMapping:GitopsAppProjectMapping": "GitopsAppProjectMapping"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/gitopsApplicationset",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/gitopsApplicationset:GitopsApplicationset": "GitopsApplicationset"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/gitopsFilters",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/gitopsFilters:GitopsFilters": "GitopsFilters"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/gitxWebhook",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/gitxWebhook:GitxWebhook": "GitxWebhook"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/harRegistry",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/harRegistry:HarRegistry": "HarRegistry"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/helmConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/helmConnector:HelmConnector": "HelmConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/iacmDefaultPipeline",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/iacmDefaultPipeline:IacmDefaultPipeline": "IacmDefaultPipeline"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/idpCatalogEntity",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/idpCatalogEntity:IdpCatalogEntity": "IdpCatalogEntity"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/idpEnvironment",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/idpEnvironment:IdpEnvironment": "IdpEnvironment"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/idpEnvironmentBlueprint",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/idpEnvironmentBlueprint:IdpEnvironmentBlueprint": "IdpEnvironmentBlueprint"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/infraModule",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/infraModule:InfraModule": "InfraModule"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/infraModuleTesting",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/infraModuleTesting:InfraModuleTesting": "InfraModuleTesting"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/infraVariableSet",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/infraVariableSet:InfraVariableSet": "InfraVariableSet"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/infrastructure",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/infrastructure:Infrastructure": "Infrastructure"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/inputSet",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/inputSet:InputSet": "InputSet"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/ipAllowlist",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/ipAllowlist:IpAllowlist": "IpAllowlist"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/jenkinsConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/jenkinsConnector:JenkinsConnector": "JenkinsConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/jiraConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/jiraConnector:JiraConnector": "JiraConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/kubernetesCloudCostConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/kubernetesCloudCostConnector:KubernetesCloudCostConnector": "KubernetesCloudCostConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/kubernetesConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/kubernetesConnector:KubernetesConnector": "KubernetesConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/manualFreeze",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/manualFreeze:ManualFreeze": "ManualFreeze"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/monitoredService",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/monitoredService:MonitoredService": "MonitoredService"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/newrelicConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/newrelicConnector:NewrelicConnector": "NewrelicConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/nexusConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/nexusConnector:NexusConnector": "NexusConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/notificationRule",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/notificationRule:NotificationRule": "NotificationRule"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/ociHelmConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/ociHelmConnector:OciHelmConnector": "OciHelmConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/organization",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/organization:Organization": "Organization"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/overrides",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/overrides:Overrides": "Overrides"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/pagerdutyConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/pagerdutyConnector:PagerdutyConnector": "PagerdutyConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/pipeline",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/pipeline:Pipeline": "Pipeline"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/pipelineCentralNotificationRule",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/pipelineCentralNotificationRule:PipelineCentralNotificationRule": "PipelineCentralNotificationRule"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/pipelineFilters",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/pipelineFilters:PipelineFilters": "PipelineFilters"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/policy",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/policySet",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/policySet:PolicySet": "PolicySet"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/project",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/project:Project": "Project"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/prometheusConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/prometheusConnector:PrometheusConnector": "PrometheusConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/provider",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/provider:Provider": "Provider"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/repo",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/repo:Repo": "Repo"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/repoRuleBranch",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/repoRuleBranch:RepoRuleBranch": "RepoRuleBranch"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/repoWebhook",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/repoWebhook:RepoWebhook": "RepoWebhook"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/resourceGroup",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/resourceGroup:ResourceGroup": "ResourceGroup"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/roleAssignments",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/roleAssignments:RoleAssignments": "RoleAssignments"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/roles",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/roles:Roles": "Roles"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/secretFile",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/secretFile:SecretFile": "SecretFile"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/secretSshkey",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/secretSshkey:SecretSshkey": "SecretSshkey"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/secretText",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/secretText:SecretText": "SecretText"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/secretWinrm",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/secretWinrm:SecretWinrm": "SecretWinrm"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/service",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/service:Service": "Service"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/serviceAccount",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/serviceAccount:ServiceAccount": "ServiceAccount"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/serviceNowConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/serviceNowConnector:ServiceNowConnector": "ServiceNowConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/serviceOverridesV2",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/serviceOverridesV2:ServiceOverridesV2": "ServiceOverridesV2"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/slo",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/slo:Slo": "Slo"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/splunkConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/splunkConnector:SplunkConnector": "SplunkConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/spotConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/spotConnector:SpotConnector": "SpotConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/sumologicConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/sumologicConnector:SumologicConnector": "SumologicConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/tasConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/tasConnector:TasConnector": "TasConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/template",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/template:Template": "Template"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/templateFilters",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/templateFilters:TemplateFilters": "TemplateFilters"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/terraformCloudConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/terraformCloudConnector:TerraformCloudConnector": "TerraformCloudConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/token",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/token:Token": "Token"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/triggers",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/triggers:Triggers": "Triggers"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/user",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/user:User": "User"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/usergroup",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/usergroup:Usergroup": "Usergroup"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/variables",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/variables:Variables": "Variables"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/vaultConnector",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/vaultConnector:VaultConnector": "VaultConnector"
  }
 },
 {
  "pkg": "harness",
  "mod": "platform/workspace",
  "fqn": "pulumi_harness.platform",
  "classes": {
   "harness:platform/workspace:Workspace": "Workspace"
  }
 },
 {
  "pkg": "harness",
  "mod": "service/ami",
  "fqn": "pulumi_harness.service",
  "classes": {
   "harness:service/ami:Ami": "Ami"
  }
 },
 {
  "pkg": "harness",
  "mod": "service/codedeploy",
  "fqn": "pulumi_harness.service",
  "classes": {
   "harness:service/codedeploy:Codedeploy": "Codedeploy"
  }
 },
 {
  "pkg": "harness",
  "mod": "service/discoveryAgent",
  "fqn": "pulumi_harness.service",
  "classes": {
   "harness:service/discoveryAgent:DiscoveryAgent": "DiscoveryAgent"
  }
 },
 {
  "pkg": "harness",
  "mod": "service/discoverySetting",
  "fqn": "pulumi_harness.service",
  "classes": {
   "harness:service/discoverySetting:DiscoverySetting": "DiscoverySetting"
  }
 },
 {
  "pkg": "harness",
  "mod": "service/ecs",
  "fqn": "pulumi_harness.service",
  "classes": {
   "harness:service/ecs:Ecs": "Ecs"
  }
 },
 {
  "pkg": "harness",
  "mod": "service/helm",
  "fqn": "pulumi_harness.service",
  "classes": {
   "harness:service/helm:Helm": "Helm"
  }
 },
 {
  "pkg": "harness",
  "mod": "service/kubernetes",
  "fqn": "pulumi_harness.service",
  "classes": {
   "harness:service/kubernetes:Kubernetes": "Kubernetes"
  }
 },
 {
  "pkg": "harness",
  "mod": "service/lambda",
  "fqn": "pulumi_harness.service",
  "classes": {
   "harness:service/lambda:Lambda": "Lambda"
  }
 },
 {
  "pkg": "harness",
  "mod": "service/ssh",
  "fqn": "pulumi_harness.service",
  "classes": {
   "harness:service/ssh:Ssh": "Ssh"
  }
 },
 {
  "pkg": "harness",
  "mod": "service/tanzu",
  "fqn": "pulumi_harness.service",
  "classes": {
   "harness:service/tanzu:Tanzu": "Tanzu"
  }
 },
 {
  "pkg": "harness",
  "mod": "service/winrm",
  "fqn": "pulumi_harness.service",
  "classes": {
   "harness:service/winrm:Winrm": "Winrm"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "harness",
  "token": "pulumi:providers:harness",
  "fqn": "pulumi_harness",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDiscoveryAgentResult',
    'AwaitableGetDiscoveryAgentResult',
    'get_discovery_agent',
    'get_discovery_agent_output',
]

@pulumi.output_type
class GetDiscoveryAgentResult:
    """
    A collection of values returned by getDiscoveryAgent.
    """
    def __init__(__self__, configs=None, correlation_id=None, created_at=None, created_by=None, description=None, environment_identifier=None, id=None, identity=None, installation_details=None, installation_type=None, name=None, network_map_count=None, org_identifier=None, permanent_installation=None, project_identifier=None, removed=None, removed_at=None, service_count=None, tags=None, updated_at=None, updated_by=None, webhook_url=None):
        if configs and not isinstance(configs, list):
            raise TypeError("Expected argument 'configs' to be a list")
        pulumi.set(__self__, "configs", configs)
        if correlation_id and not isinstance(correlation_id, str):
            raise TypeError("Expected argument 'correlation_id' to be a str")
        pulumi.set(__self__, "correlation_id", correlation_id)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if environment_identifier and not isinstance(environment_identifier, str):
            raise TypeError("Expected argument 'environment_identifier' to be a str")
        pulumi.set(__self__, "environment_identifier", environment_identifier)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identity and not isinstance(identity, str):
            raise TypeError("Expected argument 'identity' to be a str")
        pulumi.set(__self__, "identity", identity)
        if installation_details and not isinstance(installation_details, list):
            raise TypeError("Expected argument 'installation_details' to be a list")
        pulumi.set(__self__, "installation_details", installation_details)
        if installation_type and not isinstance(installation_type, str):
            raise TypeError("Expected argument 'installation_type' to be a str")
        pulumi.set(__self__, "installation_type", installation_type)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if network_map_count and not isinstance(network_map_count, int):
            raise TypeError("Expected argument 'network_map_count' to be a int")
        pulumi.set(__self__, "network_map_count", network_map_count)
        if org_identifier and not isinstance(org_identifier, str):
            raise TypeError("Expected argument 'org_identifier' to be a str")
        pulumi.set(__self__, "org_identifier", org_identifier)
        if permanent_installation and not isinstance(permanent_installation, bool):
            raise TypeError("Expected argument 'permanent_installation' to be a bool")
        pulumi.set(__self__, "permanent_installation", permanent_installation)
        if project_identifier and not isinstance(project_identifier, str):
            raise TypeError("Expected argument 'project_identifier' to be a str")
        pulumi.set(__self__, "project_identifier", project_identifier)
        if removed and not isinstance(removed, bool):
            raise TypeError("Expected argument 'removed' to be a bool")
        pulumi.set(__self__, "removed", removed)
        if removed_at and not isinstance(removed_at, str):
            raise TypeError("Expected argument 'removed_at' to be a str")
        pulumi.set(__self__, "removed_at", removed_at)
        if service_count and not isinstance(service_count, int):
            raise TypeError("Expected argument 'service_count' to be a int")
        pulumi.set(__self__, "service_count", service_count)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if updated_by and not isinstance(updated_by, str):
            raise TypeError("Expected argument 'updated_by' to be a str")
        pulumi.set(__self__, "updated_by", updated_by)
        if webhook_url and not isinstance(webhook_url, str):
            raise TypeError("Expected argument 'webhook_url' to be a str")
        pulumi.set(__self__, "webhook_url", webhook_url)

    @_builtins.property
    @pulumi.getter
    def configs(self) -> Sequence['outputs.GetDiscoveryAgentConfigResult']:
        """
        Configuration for the agent.
        """
        return pulumi.get(self, "configs")

    @_builtins.property
    @pulumi.getter(name="correlationId")
    def correlation_id(self) -> _builtins.str:
        """
        Correlation ID for the agent.
        """
        return pulumi.get(self, "correlation_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        Timestamp when the agent was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> _builtins.str:
        """
        User who created the agent.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the agent.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="environmentIdentifier")
    def environment_identifier(self) -> _builtins.str:
        """
        The environment identifier of the agent. This is a required field.
        """
        return pulumi.get(self, "environment_identifier")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier of the agent.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identity(self) -> Optional[_builtins.str]:
        """
        The unique identity of the agent. Either this or 'name' must be provided.
        """
        return pulumi.get(self, "identity")

    @_builtins.property
    @pulumi.getter(name="installationDetails")
    def installation_details(self) -> Sequence['outputs.GetDiscoveryAgentInstallationDetailResult']:
        """
        Installation details of the agent.
        """
        return pulumi.get(self, "installation_details")

    @_builtins.property
    @pulumi.getter(name="installationType")
    def installation_type(self) -> _builtins.str:
        """
        Type of installation for the agent.
        """
        return pulumi.get(self, "installation_type")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        The name of the agent. Either this or 'identity' must be provided.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="networkMapCount")
    def network_map_count(self) -> _builtins.int:
        """
        Number of network maps associated with this agent.
        """
        return pulumi.get(self, "network_map_count")

    @_builtins.property
    @pulumi.getter(name="orgIdentifier")
    def org_identifier(self) -> Optional[_builtins.str]:
        """
        The organization identifier of the agent (optional). Must be 1-64 characters and contain only alphanumeric characters, hyphens, or underscores.
        """
        return pulumi.get(self, "org_identifier")

    @_builtins.property
    @pulumi.getter(name="permanentInstallation")
    def permanent_installation(self) -> _builtins.bool:
        """
        Whether this is a permanent installation.
        """
        return pulumi.get(self, "permanent_installation")

    @_builtins.property
    @pulumi.getter(name="projectIdentifier")
    def project_identifier(self) -> Optional[_builtins.str]:
        """
        The project identifier of the agent (optional). Must be 1-64 characters and contain only alphanumeric characters, hyphens, or underscores.
        """
        return pulumi.get(self, "project_identifier")

    @_builtins.property
    @pulumi.getter
    def removed(self) -> _builtins.bool:
        """
        Whether the agent has been removed.
        """
        return pulumi.get(self, "removed")

    @_builtins.property
    @pulumi.getter(name="removedAt")
    def removed_at(self) -> _builtins.str:
        """
        Timestamp when the agent was removed.
        """
        return pulumi.get(self, "removed_at")

    @_builtins.property
    @pulumi.getter(name="serviceCount")
    def service_count(self) -> _builtins.int:
        """
        Number of services managed by this agent.
        """
        return pulumi.get(self, "service_count")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Key-value list of resource tags for the agent.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        Timestamp when the agent was last updated.
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> _builtins.str:
        """
        User who last updated the agent.
        """
        return pulumi.get(self, "updated_by")

    @_builtins.property
    @pulumi.getter(name="webhookUrl")
    def webhook_url(self) -> _builtins.str:
        """
        Webhook URL for the agent.
        """
        return pulumi.get(self, "webhook_url")


class AwaitableGetDiscoveryAgentResult(GetDiscoveryAgentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDiscoveryAgentResult(
            configs=self.configs,
            correlation_id=self.correlation_id,
            created_at=self.created_at,
            created_by=self.created_by,
            description=self.description,
            environment_identifier=self.environment_identifier,
            id=self.id,
            identity=self.identity,
            installation_details=self.installation_details,
            installation_type=self.installation_type,
            name=self.name,
            network_map_count=self.network_map_count,
            org_identifier=self.org_identifier,
            permanent_installation=self.permanent_installation,
            project_identifier=self.project_identifier,
            removed=self.removed,
            removed_at=self.removed_at,
            service_count=self.service_count,
            tags=self.tags,
            updated_at=self.updated_at,
            updated_by=self.updated_by,
            webhook_url=self.webhook_url)


def get_discovery_agent(environment_identifier: Optional[_builtins.str] = None,
                        identity: Optional[_builtins.str] = None,
                        name: Optional[_builtins.str] = None,
                        org_identifier: Optional[_builtins.str] = None,
                        project_identifier: Optional[_builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDiscoveryAgentResult:
    """
    Data source for retrieving a Harness Service Discovery Agent.

    This data source allows you to fetch details of a Service Discovery Agent using either its unique identifier or name.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # Data source to fetch a specific agent by name
    by_name = harness.service.get_discovery_agent(name="example-agent",
        org_identifier=org_identifier,
        project_identifier=project_identifier,
        environment_identifier=environment_identifier)
    pulumi.export("agentDetailsByName", by_name)
    # Data source to fetch a specific agent by identity
    by_identity = harness.service.get_discovery_agent(identity="example-infra",
        org_identifier=org_identifier,
        project_identifier=project_identifier,
        environment_identifier=environment_identifier)
    pulumi.export("agentDetailsByIdentity", by_identity)
    ```


    :param _builtins.str environment_identifier: The environment identifier of the agent. This is a required field.
    :param _builtins.str identity: The unique identity of the agent. Either this or 'name' must be provided.
    :param _builtins.str name: The name of the agent. Either this or 'identity' must be provided.
    :param _builtins.str org_identifier: The organization identifier of the agent (optional). Must be 1-64 characters and contain only alphanumeric characters, hyphens, or underscores.
    :param _builtins.str project_identifier: The project identifier of the agent (optional). Must be 1-64 characters and contain only alphanumeric characters, hyphens, or underscores.
    """
    __args__ = dict()
    __args__['environmentIdentifier'] = environment_identifier
    __args__['identity'] = identity
    __args__['name'] = name
    __args__['orgIdentifier'] = org_identifier
    __args__['projectIdentifier'] = project_identifier
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:service/getDiscoveryAgent:getDiscoveryAgent', __args__, opts=opts, typ=GetDiscoveryAgentResult).value

    return AwaitableGetDiscoveryAgentResult(
        configs=pulumi.get(__ret__, 'configs'),
        correlation_id=pulumi.get(__ret__, 'correlation_id'),
        created_at=pulumi.get(__ret__, 'created_at'),
        created_by=pulumi.get(__ret__, 'created_by'),
        description=pulumi.get(__ret__, 'description'),
        environment_identifier=pulumi.get(__ret__, 'environment_identifier'),
        id=pulumi.get(__ret__, 'id'),
        identity=pulumi.get(__ret__, 'identity'),
        installation_details=pulumi.get(__ret__, 'installation_details'),
        installation_type=pulumi.get(__ret__, 'installation_type'),
        name=pulumi.get(__ret__, 'name'),
        network_map_count=pulumi.get(__ret__, 'network_map_count'),
        org_identifier=pulumi.get(__ret__, 'org_identifier'),
        permanent_installation=pulumi.get(__ret__, 'permanent_installation'),
        project_identifier=pulumi.get(__ret__, 'project_identifier'),
        removed=pulumi.get(__ret__, 'removed'),
        removed_at=pulumi.get(__ret__, 'removed_at'),
        service_count=pulumi.get(__ret__, 'service_count'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        updated_by=pulumi.get(__ret__, 'updated_by'),
        webhook_url=pulumi.get(__ret__, 'webhook_url'))
def get_discovery_agent_output(environment_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                               identity: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               org_identifier: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               project_identifier: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDiscoveryAgentResult]:
    """
    Data source for retrieving a Harness Service Discovery Agent.

    This data source allows you to fetch details of a Service Discovery Agent using either its unique identifier or name.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # Data source to fetch a specific agent by name
    by_name = harness.service.get_discovery_agent(name="example-agent",
        org_identifier=org_identifier,
        project_identifier=project_identifier,
        environment_identifier=environment_identifier)
    pulumi.export("agentDetailsByName", by_name)
    # Data source to fetch a specific agent by identity
    by_identity = harness.service.get_discovery_agent(identity="example-infra",
        org_identifier=org_identifier,
        project_identifier=project_identifier,
        environment_identifier=environment_identifier)
    pulumi.export("agentDetailsByIdentity", by_identity)
    ```


    :param _builtins.str environment_identifier: The environment identifier of the agent. This is a required field.
    :param _builtins.str identity: The unique identity of the agent. Either this or 'name' must be provided.
    :param _builtins.str name: The name of the agent. Either this or 'identity' must be provided.
    :param _builtins.str org_identifier: The organization identifier of the agent (optional). Must be 1-64 characters and contain only alphanumeric characters, hyphens, or underscores.
    :param _builtins.str project_identifier: The project identifier of the agent (optional). Must be 1-64 characters and contain only alphanumeric characters, hyphens, or underscores.
    """
    __args__ = dict()
    __args__['environmentIdentifier'] = environment_identifier
    __args__['identity'] = identity
    __args__['name'] = name
    __args__['orgIdentifier'] = org_identifier
    __args__['projectIdentifier'] = project_identifier
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:service/getDiscoveryAgent:getDiscoveryAgent', __args__, opts=opts, typ=GetDiscoveryAgentResult)
    return __ret__.apply(lambda __response__: GetDiscoveryAgentResult(
        configs=pulumi.get(__response__, 'configs'),
        correlation_id=pulumi.get(__response__, 'correlation_id'),
        created_at=pulumi.get(__response__, 'created_at'),
        created_by=pulumi.get(__response__, 'created_by'),
        description=pulumi.get(__response__, 'description'),
        environment_identifier=pulumi.get(__response__, 'environment_identifier'),
        id=pulumi.get(__response__, 'id'),
        identity=pulumi.get(__response__, 'identity'),
        installation_details=pulumi.get(__response__, 'installation_details'),
        installation_type=pulumi.get(__response__, 'installation_type'),
        name=pulumi.get(__response__, 'name'),
        network_map_count=pulumi.get(__response__, 'network_map_count'),
        org_identifier=pulumi.get(__response__, 'org_identifier'),
        permanent_installation=pulumi.get(__response__, 'permanent_installation'),
        project_identifier=pulumi.get(__response__, 'project_identifier'),
        removed=pulumi.get(__response__, 'removed'),
        removed_at=pulumi.get(__response__, 'removed_at'),
        service_count=pulumi.get(__response__, 'service_count'),
        tags=pulumi.get(__response__, 'tags'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        updated_by=pulumi.get(__response__, 'updated_by'),
        webhook_url=pulumi.get(__response__, 'webhook_url')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetRoleAssignmentsResult',
    'AwaitableGetRoleAssignmentsResult',
    'get_role_assignments',
    'get_role_assignments_output',
]

@pulumi.output_type
class GetRoleAssignmentsResult:
    """
    A collection of values returned by getRoleAssignments.
    """
    def __init__(__self__, disabled=None, id=None, identifier=None, managed=None, org_id=None, principals=None, project_id=None, resource_group_identifier=None, role_identifier=None):
        if disabled and not isinstance(disabled, bool):
            raise TypeError("Expected argument 'disabled' to be a bool")
        pulumi.set(__self__, "disabled", disabled)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if managed and not isinstance(managed, bool):
            raise TypeError("Expected argument 'managed' to be a bool")
        pulumi.set(__self__, "managed", managed)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if principals and not isinstance(principals, list):
            raise TypeError("Expected argument 'principals' to be a list")
        pulumi.set(__self__, "principals", principals)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if resource_group_identifier and not isinstance(resource_group_identifier, str):
            raise TypeError("Expected argument 'resource_group_identifier' to be a str")
        pulumi.set(__self__, "resource_group_identifier", resource_group_identifier)
        if role_identifier and not isinstance(role_identifier, str):
            raise TypeError("Expected argument 'role_identifier' to be a str")
        pulumi.set(__self__, "role_identifier", role_identifier)

    @_builtins.property
    @pulumi.getter
    def disabled(self) -> _builtins.bool:
        """
        Disabled or not.
        """
        return pulumi.get(self, "disabled")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Identifier for role assignment.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def managed(self) -> _builtins.bool:
        """
        Managed or not.
        """
        return pulumi.get(self, "managed")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Org identifier.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    def principals(self) -> Sequence['outputs.GetRoleAssignmentsPrincipalResult']:
        """
        Principal.
        """
        return pulumi.get(self, "principals")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Project Identifier
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="resourceGroupIdentifier")
    def resource_group_identifier(self) -> _builtins.str:
        """
        Resource group identifier.
        """
        return pulumi.get(self, "resource_group_identifier")

    @_builtins.property
    @pulumi.getter(name="roleIdentifier")
    def role_identifier(self) -> _builtins.str:
        """
        Role identifier.
        """
        return pulumi.get(self, "role_identifier")


class AwaitableGetRoleAssignmentsResult(GetRoleAssignmentsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRoleAssignmentsResult(
            disabled=self.disabled,
            id=self.id,
            identifier=self.identifier,
            managed=self.managed,
            org_id=self.org_id,
            principals=self.principals,
            project_id=self.project_id,
            resource_group_identifier=self.resource_group_identifier,
            role_identifier=self.role_identifier)


def get_role_assignments(identifier: Optional[_builtins.str] = None,
                         org_id: Optional[_builtins.str] = None,
                         project_id: Optional[_builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRoleAssignmentsResult:
    """
    Data source for retrieving role assignment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_role_assignments(identifier="identifier",
        org_id="org_id",
        project_id="project_id")
    ```


    :param _builtins.str identifier: Identifier for role assignment.
    :param _builtins.str org_id: Org identifier.
    :param _builtins.str project_id: Project Identifier
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getRoleAssignments:getRoleAssignments', __args__, opts=opts, typ=GetRoleAssignmentsResult).value

    return AwaitableGetRoleAssignmentsResult(
        disabled=pulumi.get(__ret__, 'disabled'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        managed=pulumi.get(__ret__, 'managed'),
        org_id=pulumi.get(__ret__, 'org_id'),
        principals=pulumi.get(__ret__, 'principals'),
        project_id=pulumi.get(__ret__, 'project_id'),
        resource_group_identifier=pulumi.get(__ret__, 'resource_group_identifier'),
        role_identifier=pulumi.get(__ret__, 'role_identifier'))
def get_role_assignments_output(identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRoleAssignmentsResult]:
    """
    Data source for retrieving role assignment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_role_assignments(identifier="identifier",
        org_id="org_id",
        project_id="project_id")
    ```


    :param _builtins.str identifier: Identifier for role assignment.
    :param _builtins.str org_id: Org identifier.
    :param _builtins.str project_id: Project Identifier
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getRoleAssignments:getRoleAssignments', __args__, opts=opts, typ=GetRoleAssignmentsResult)
    return __ret__.apply(lambda __response__: GetRoleAssignmentsResult(
        disabled=pulumi.get(__response__, 'disabled'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        managed=pulumi.get(__response__, 'managed'),
        org_id=pulumi.get(__response__, 'org_id'),
        principals=pulumi.get(__response__, 'principals'),
        project_id=pulumi.get(__response__, 'project_id'),
        resource_group_identifier=pulumi.get(__response__, 'resource_group_identifier'),
        role_identifier=pulumi.get(__response__, 'role_identifier')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetChaosInfrastructureResult',
    'AwaitableGetChaosInfrastructureResult',
    'get_chaos_infrastructure',
    'get_chaos_infrastructure_output',
]

@pulumi.output_type
class GetChaosInfrastructureResult:
    """
    A collection of values returned by getChaosInfrastructure.
    """
    def __init__(__self__, environment_id=None, id=None, identifier=None, org_id=None, project_id=None):
        if environment_id and not isinstance(environment_id, str):
            raise TypeError("Expected argument 'environment_id' to be a str")
        pulumi.set(__self__, "environment_id", environment_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)

    @_builtins.property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> _builtins.str:
        """
        Environment identifier of the chaos infrastructure.
        """
        return pulumi.get(self, "environment_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Identifier of the chaos infrastructure.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> _builtins.str:
        """
        Identifier of the organization in which the chaos infrastructure is configured.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        Identifier of the project in which the chaos infrastructure is configured.
        """
        return pulumi.get(self, "project_id")


class AwaitableGetChaosInfrastructureResult(GetChaosInfrastructureResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetChaosInfrastructureResult(
            environment_id=self.environment_id,
            id=self.id,
            identifier=self.identifier,
            org_id=self.org_id,
            project_id=self.project_id)


def get_chaos_infrastructure(environment_id: Optional[_builtins.str] = None,
                             identifier: Optional[_builtins.str] = None,
                             org_id: Optional[_builtins.str] = None,
                             project_id: Optional[_builtins.str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetChaosInfrastructureResult:
    """
    Data source for retrieving a chaos infrastructure.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.get_chaos_infrastructure(identifier="identifier",
        org_id="org_id",
        project_id="project_id",
        environment_id="env_id")
    ```


    :param _builtins.str environment_id: Environment identifier of the chaos infrastructure.
    :param _builtins.str identifier: Identifier of the chaos infrastructure.
    :param _builtins.str org_id: Identifier of the organization in which the chaos infrastructure is configured.
    :param _builtins.str project_id: Identifier of the project in which the chaos infrastructure is configured.
    """
    __args__ = dict()
    __args__['environmentId'] = environment_id
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:index/getChaosInfrastructure:getChaosInfrastructure', __args__, opts=opts, typ=GetChaosInfrastructureResult).value

    return AwaitableGetChaosInfrastructureResult(
        environment_id=pulumi.get(__ret__, 'environment_id'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'))
def get_chaos_infrastructure_output(environment_id: Optional[pulumi.Input[_builtins.str]] = None,
                                    identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                    org_id: Optional[pulumi.Input[_builtins.str]] = None,
                                    project_id: Optional[pulumi.Input[_builtins.str]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetChaosInfrastructureResult]:
    """
    Data source for retrieving a chaos infrastructure.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.get_chaos_infrastructure(identifier="identifier",
        org_id="org_id",
        project_id="project_id",
        environment_id="env_id")
    ```


    :param _builtins.str environment_id: Environment identifier of the chaos infrastructure.
    :param _builtins.str identifier: Identifier of the chaos infrastructure.
    :param _builtins.str org_id: Identifier of the organization in which the chaos infrastructure is configured.
    :param _builtins.str project_id: Identifier of the project in which the chaos infrastructure is configured.
    """
    __args__ = dict()
    __args__['environmentId'] = environment_id
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:index/getChaosInfrastructure:getChaosInfrastructure', __args__, opts=opts, typ=GetChaosInfrastructureResult)
    return __ret__.apply(lambda __response__: GetChaosInfrastructureResult(
        environment_id=pulumi.get(__response__, 'environment_id'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetServiceListResult',
    'AwaitableGetServiceListResult',
    'get_service_list',
    'get_service_list_output',
]

@pulumi.output_type
class GetServiceListResult:
    """
    A collection of values returned by getServiceList.
    """
    def __init__(__self__, id=None, org_id=None, page=None, project_id=None, services=None, size=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if page and not isinstance(page, int):
            raise TypeError("Expected argument 'page' to be a int")
        pulumi.set(__self__, "page", page)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if services and not isinstance(services, list):
            raise TypeError("Expected argument 'services' to be a list")
        pulumi.set(__self__, "services", services)
        if size and not isinstance(size, int):
            raise TypeError("Expected argument 'size' to be a int")
        pulumi.set(__self__, "size", size)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    def page(self) -> Optional[_builtins.int]:
        """
        Page index of the results to fetch. Default: 0
        """
        return pulumi.get(self, "page")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def services(self) -> Sequence['outputs.GetServiceListServiceResult']:
        return pulumi.get(self, "services")

    @_builtins.property
    @pulumi.getter
    def size(self) -> Optional[_builtins.int]:
        """
        Results per page. Default: 100; Max: 1000
        """
        return pulumi.get(self, "size")


class AwaitableGetServiceListResult(GetServiceListResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServiceListResult(
            id=self.id,
            org_id=self.org_id,
            page=self.page,
            project_id=self.project_id,
            services=self.services,
            size=self.size)


def get_service_list(org_id: Optional[_builtins.str] = None,
                     page: Optional[_builtins.int] = None,
                     project_id: Optional[_builtins.str] = None,
                     size: Optional[_builtins.int] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServiceListResult:
    """
    Data source for retrieving a Harness service List.


    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.int page: Page index of the results to fetch. Default: 0
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.int size: Results per page. Default: 100; Max: 1000
    """
    __args__ = dict()
    __args__['orgId'] = org_id
    __args__['page'] = page
    __args__['projectId'] = project_id
    __args__['size'] = size
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getServiceList:getServiceList', __args__, opts=opts, typ=GetServiceListResult).value

    return AwaitableGetServiceListResult(
        id=pulumi.get(__ret__, 'id'),
        org_id=pulumi.get(__ret__, 'org_id'),
        page=pulumi.get(__ret__, 'page'),
        project_id=pulumi.get(__ret__, 'project_id'),
        services=pulumi.get(__ret__, 'services'),
        size=pulumi.get(__ret__, 'size'))
def get_service_list_output(org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            page: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                            project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            size: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetServiceListResult]:
    """
    Data source for retrieving a Harness service List.


    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.int page: Page index of the results to fetch. Default: 0
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.int size: Results per page. Default: 100; Max: 1000
    """
    __args__ = dict()
    __args__['orgId'] = org_id
    __args__['page'] = page
    __args__['projectId'] = project_id
    __args__['size'] = size
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getServiceList:getServiceList', __args__, opts=opts, typ=GetServiceListResult)
    return __ret__.apply(lambda __response__: GetServiceListResult(
        id=pulumi.get(__response__, 'id'),
        org_id=pulumi.get(__response__, 'org_id'),
        page=pulumi.get(__response__, 'page'),
        project_id=pulumi.get(__response__, 'project_id'),
        services=pulumi.get(__response__, 'services'),
        size=pulumi.get(__response__, 'size')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'OrchestratorConfigBinpacking',
    'OrchestratorConfigBinpackingDisruption',
    'OrchestratorConfigBinpackingDisruptionBudget',
    'OrchestratorConfigBinpackingDisruptionBudgetSchedule',
    'OrchestratorConfigBinpackingPodEviction',
    'OrchestratorConfigBinpackingPodEvictionThreshold',
    'OrchestratorConfigCommitmentIntegration',
    'OrchestratorConfigDistribution',
    'OrchestratorConfigNodePreferences',
    'OrchestratorConfigReplacementSchedule',
    'OrchestratorConfigReplacementScheduleAppliesTo',
    'OrchestratorConfigReplacementScheduleWindowDetails',
    'GetOrchestratorConfigBinpackingResult',
    'GetOrchestratorConfigBinpackingDisruptionResult',
    'GetOrchestratorConfigBinpackingDisruptionBudgetResult',
    'GetOrchestratorConfigBinpackingDisruptionBudgetScheduleResult',
    'GetOrchestratorConfigBinpackingPodEvictionResult',
    'GetOrchestratorConfigBinpackingPodEvictionThresholdResult',
    'GetOrchestratorConfigCommitmentIntegrationResult',
    'GetOrchestratorConfigDistributionResult',
    'GetOrchestratorConfigNodePreferencesResult',
    'GetOrchestratorConfigReplacementScheduleResult',
    'GetOrchestratorConfigReplacementScheduleAppliesToResult',
    'GetOrchestratorConfigReplacementScheduleWindowDetailsResult',
]

@pulumi.output_type
class OrchestratorConfigBinpacking(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "podEviction":
            suggest = "pod_eviction"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in OrchestratorConfigBinpacking. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        OrchestratorConfigBinpacking.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        OrchestratorConfigBinpacking.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 disruption: Optional['outputs.OrchestratorConfigBinpackingDisruption'] = None,
                 pod_eviction: Optional['outputs.OrchestratorConfigBinpackingPodEviction'] = None):
        """
        :param 'OrchestratorConfigBinpackingDisruptionArgs' disruption: Harness disruption configuration
        :param 'OrchestratorConfigBinpackingPodEvictionArgs' pod_eviction: Harness Pod Evictor Configuration
        """
        if disruption is not None:
            pulumi.set(__self__, "disruption", disruption)
        if pod_eviction is not None:
            pulumi.set(__self__, "pod_eviction", pod_eviction)

    @_builtins.property
    @pulumi.getter
    def disruption(self) -> Optional['outputs.OrchestratorConfigBinpackingDisruption']:
        """
        Harness disruption configuration
        """
        return pulumi.get(self, "disruption")

    @_builtins.property
    @pulumi.getter(name="podEviction")
    def pod_eviction(self) -> Optional['outputs.OrchestratorConfigBinpackingPodEviction']:
        """
        Harness Pod Evictor Configuration
        """
        return pulumi.get(self, "pod_eviction")


@pulumi.output_type
class OrchestratorConfigBinpackingDisruption(dict):
    def __init__(__self__, *,
                 budgets: Optional[Sequence['outputs.OrchestratorConfigBinpackingDisruptionBudget']] = None,
                 criteria: Optional[_builtins.str] = None,
                 delay: Optional[_builtins.str] = None):
        """
        :param Sequence['OrchestratorConfigBinpackingDisruptionBudgetArgs'] budgets: Budgets for disruption
        :param _builtins.str criteria: Criteria for considering a nodes for disruption
        :param _builtins.str delay: Deletion delay
        """
        if budgets is not None:
            pulumi.set(__self__, "budgets", budgets)
        if criteria is not None:
            pulumi.set(__self__, "criteria", criteria)
        if delay is not None:
            pulumi.set(__self__, "delay", delay)

    @_builtins.property
    @pulumi.getter
    def budgets(self) -> Optional[Sequence['outputs.OrchestratorConfigBinpackingDisruptionBudget']]:
        """
        Budgets for disruption
        """
        return pulumi.get(self, "budgets")

    @_builtins.property
    @pulumi.getter
    def criteria(self) -> Optional[_builtins.str]:
        """
        Criteria for considering a nodes for disruption
        """
        return pulumi.get(self, "criteria")

    @_builtins.property
    @pulumi.getter
    def delay(self) -> Optional[_builtins.str]:
        """
        Deletion delay
        """
        return pulumi.get(self, "delay")


@pulumi.output_type
class OrchestratorConfigBinpackingDisruptionBudget(dict):
    def __init__(__self__, *,
                 nodes: _builtins.str,
                 reasons: Optional[Sequence[_builtins.str]] = None,
                 schedule: Optional['outputs.OrchestratorConfigBinpackingDisruptionBudgetSchedule'] = None):
        """
        :param _builtins.str nodes: Number or percentage of Nodes to consider for disruption
        :param Sequence[_builtins.str] reasons: Reasons for disruption
        :param 'OrchestratorConfigBinpackingDisruptionBudgetScheduleArgs' schedule: Schedule for disruption budget
        """
        pulumi.set(__self__, "nodes", nodes)
        if reasons is not None:
            pulumi.set(__self__, "reasons", reasons)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)

    @_builtins.property
    @pulumi.getter
    def nodes(self) -> _builtins.str:
        """
        Number or percentage of Nodes to consider for disruption
        """
        return pulumi.get(self, "nodes")

    @_builtins.property
    @pulumi.getter
    def reasons(self) -> Optional[Sequence[_builtins.str]]:
        """
        Reasons for disruption
        """
        return pulumi.get(self, "reasons")

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> Optional['outputs.OrchestratorConfigBinpackingDisruptionBudgetSchedule']:
        """
        Schedule for disruption budget
        """
        return pulumi.get(self, "schedule")


@pulumi.output_type
class OrchestratorConfigBinpackingDisruptionBudgetSchedule(dict):
    def __init__(__self__, *,
                 duration: _builtins.str,
                 frequency: _builtins.str):
        """
        :param _builtins.str duration: Duration for disruption budget
        :param _builtins.str frequency: Frequency for disruption budget
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "frequency", frequency)

    @_builtins.property
    @pulumi.getter
    def duration(self) -> _builtins.str:
        """
        Duration for disruption budget
        """
        return pulumi.get(self, "duration")

    @_builtins.property
    @pulumi.getter
    def frequency(self) -> _builtins.str:
        """
        Frequency for disruption budget
        """
        return pulumi.get(self, "frequency")


@pulumi.output_type
class OrchestratorConfigBinpackingPodEviction(dict):
    def __init__(__self__, *,
                 threshold: 'outputs.OrchestratorConfigBinpackingPodEvictionThreshold'):
        """
        :param 'OrchestratorConfigBinpackingPodEvictionThresholdArgs' threshold: Minimum Threshold for considering a node as underutilized
        """
        pulumi.set(__self__, "threshold", threshold)

    @_builtins.property
    @pulumi.getter
    def threshold(self) -> 'outputs.OrchestratorConfigBinpackingPodEvictionThreshold':
        """
        Minimum Threshold for considering a node as underutilized
        """
        return pulumi.get(self, "threshold")


@pulumi.output_type
class OrchestratorConfigBinpackingPodEvictionThreshold(dict):
    def __init__(__self__, *,
                 cpu: _builtins.float,
                 memory: _builtins.float):
        """
        :param _builtins.float cpu: CPU percentage for considering a node as underutilized
        :param _builtins.float memory: Memory percentage for considering a node as underutilized
        """
        pulumi.set(__self__, "cpu", cpu)
        pulumi.set(__self__, "memory", memory)

    @_builtins.property
    @pulumi.getter
    def cpu(self) -> _builtins.float:
        """
        CPU percentage for considering a node as underutilized
        """
        return pulumi.get(self, "cpu")

    @_builtins.property
    @pulumi.getter
    def memory(self) -> _builtins.float:
        """
        Memory percentage for considering a node as underutilized
        """
        return pulumi.get(self, "memory")


@pulumi.output_type
class OrchestratorConfigCommitmentIntegration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "masterAccountId":
            suggest = "master_account_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in OrchestratorConfigCommitmentIntegration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        OrchestratorConfigCommitmentIntegration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        OrchestratorConfigCommitmentIntegration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 enabled: _builtins.bool,
                 master_account_id: _builtins.str):
        """
        :param _builtins.bool enabled: Flag to enable Commitment Integration
        :param _builtins.str master_account_id: Master AWS account id for commitment integration
        """
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "master_account_id", master_account_id)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> _builtins.bool:
        """
        Flag to enable Commitment Integration
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="masterAccountId")
    def master_account_id(self) -> _builtins.str:
        """
        Master AWS account id for commitment integration
        """
        return pulumi.get(self, "master_account_id")


@pulumi.output_type
class OrchestratorConfigDistribution(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ondemandReplicaPercentage":
            suggest = "ondemand_replica_percentage"
        elif key == "baseOndemandCapacity":
            suggest = "base_ondemand_capacity"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in OrchestratorConfigDistribution. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        OrchestratorConfigDistribution.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        OrchestratorConfigDistribution.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ondemand_replica_percentage: _builtins.float,
                 base_ondemand_capacity: Optional[_builtins.int] = None,
                 selector: Optional[_builtins.str] = None,
                 strategy: Optional[_builtins.str] = None):
        """
        :param _builtins.float ondemand_replica_percentage: Percentage of on-demand replicas required for workloads
        :param _builtins.int base_ondemand_capacity: Number of minimum ondemand replicas required for workloads
        :param _builtins.str selector: Selector for choosing workloads for distribution
        :param _builtins.str strategy: Strategy for choosing spot nodes for cluster
        """
        pulumi.set(__self__, "ondemand_replica_percentage", ondemand_replica_percentage)
        if base_ondemand_capacity is not None:
            pulumi.set(__self__, "base_ondemand_capacity", base_ondemand_capacity)
        if selector is not None:
            pulumi.set(__self__, "selector", selector)
        if strategy is not None:
            pulumi.set(__self__, "strategy", strategy)

    @_builtins.property
    @pulumi.getter(name="ondemandReplicaPercentage")
    def ondemand_replica_percentage(self) -> _builtins.float:
        """
        Percentage of on-demand replicas required for workloads
        """
        return pulumi.get(self, "ondemand_replica_percentage")

    @_builtins.property
    @pulumi.getter(name="baseOndemandCapacity")
    def base_ondemand_capacity(self) -> Optional[_builtins.int]:
        """
        Number of minimum ondemand replicas required for workloads
        """
        return pulumi.get(self, "base_ondemand_capacity")

    @_builtins.property
    @pulumi.getter
    def selector(self) -> Optional[_builtins.str]:
        """
        Selector for choosing workloads for distribution
        """
        return pulumi.get(self, "selector")

    @_builtins.property
    @pulumi.getter
    def strategy(self) -> Optional[_builtins.str]:
        """
        Strategy for choosing spot nodes for cluster
        """
        return pulumi.get(self, "strategy")


@pulumi.output_type
class OrchestratorConfigNodePreferences(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "reverseFallbackInterval":
            suggest = "reverse_fallback_interval"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in OrchestratorConfigNodePreferences. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        OrchestratorConfigNodePreferences.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        OrchestratorConfigNodePreferences.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 reverse_fallback_interval: Optional[_builtins.str] = None,
                 ttl: Optional[_builtins.str] = None):
        """
        :param _builtins.str reverse_fallback_interval: Reverse fallback interval
        :param _builtins.str ttl: TTL for nodes
        """
        if reverse_fallback_interval is not None:
            pulumi.set(__self__, "reverse_fallback_interval", reverse_fallback_interval)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)

    @_builtins.property
    @pulumi.getter(name="reverseFallbackInterval")
    def reverse_fallback_interval(self) -> Optional[_builtins.str]:
        """
        Reverse fallback interval
        """
        return pulumi.get(self, "reverse_fallback_interval")

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> Optional[_builtins.str]:
        """
        TTL for nodes
        """
        return pulumi.get(self, "ttl")


@pulumi.output_type
class OrchestratorConfigReplacementSchedule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "appliesTo":
            suggest = "applies_to"
        elif key == "windowType":
            suggest = "window_type"
        elif key == "windowDetails":
            suggest = "window_details"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in OrchestratorConfigReplacementSchedule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        OrchestratorConfigReplacementSchedule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        OrchestratorConfigReplacementSchedule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 applies_to: 'outputs.OrchestratorConfigReplacementScheduleAppliesTo',
                 window_type: _builtins.str,
                 window_details: Optional['outputs.OrchestratorConfigReplacementScheduleWindowDetails'] = None):
        """
        :param 'OrchestratorConfigReplacementScheduleAppliesToArgs' applies_to: Defines the scope of the replacement schedule
        :param _builtins.str window_type: Window type for replacement schedule
        """
        pulumi.set(__self__, "applies_to", applies_to)
        pulumi.set(__self__, "window_type", window_type)
        if window_details is not None:
            pulumi.set(__self__, "window_details", window_details)

    @_builtins.property
    @pulumi.getter(name="appliesTo")
    def applies_to(self) -> 'outputs.OrchestratorConfigReplacementScheduleAppliesTo':
        """
        Defines the scope of the replacement schedule
        """
        return pulumi.get(self, "applies_to")

    @_builtins.property
    @pulumi.getter(name="windowType")
    def window_type(self) -> _builtins.str:
        """
        Window type for replacement schedule
        """
        return pulumi.get(self, "window_type")

    @_builtins.property
    @pulumi.getter(name="windowDetails")
    def window_details(self) -> Optional['outputs.OrchestratorConfigReplacementScheduleWindowDetails']:
        return pulumi.get(self, "window_details")


@pulumi.output_type
class OrchestratorConfigReplacementScheduleAppliesTo(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "harnessPodEviction":
            suggest = "harness_pod_eviction"
        elif key == "reverseFallback":
            suggest = "reverse_fallback"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in OrchestratorConfigReplacementScheduleAppliesTo. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        OrchestratorConfigReplacementScheduleAppliesTo.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        OrchestratorConfigReplacementScheduleAppliesTo.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 consolidation: _builtins.bool,
                 harness_pod_eviction: _builtins.bool,
                 reverse_fallback: _builtins.bool):
        pulumi.set(__self__, "consolidation", consolidation)
        pulumi.set(__self__, "harness_pod_eviction", harness_pod_eviction)
        pulumi.set(__self__, "reverse_fallback", reverse_fallback)

    @_builtins.property
    @pulumi.getter
    def consolidation(self) -> _builtins.bool:
        return pulumi.get(self, "consolidation")

    @_builtins.property
    @pulumi.getter(name="harnessPodEviction")
    def harness_pod_eviction(self) -> _builtins.bool:
        return pulumi.get(self, "harness_pod_eviction")

    @_builtins.property
    @pulumi.getter(name="reverseFallback")
    def reverse_fallback(self) -> _builtins.bool:
        return pulumi.get(self, "reverse_fallback")


@pulumi.output_type
class OrchestratorConfigReplacementScheduleWindowDetails(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "timeZone":
            suggest = "time_zone"
        elif key == "allDay":
            suggest = "all_day"
        elif key == "endTime":
            suggest = "end_time"
        elif key == "startTime":
            suggest = "start_time"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in OrchestratorConfigReplacementScheduleWindowDetails. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        OrchestratorConfigReplacementScheduleWindowDetails.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        OrchestratorConfigReplacementScheduleWindowDetails.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 days: Sequence[_builtins.str],
                 time_zone: _builtins.str,
                 all_day: Optional[_builtins.bool] = None,
                 end_time: Optional[_builtins.str] = None,
                 start_time: Optional[_builtins.str] = None):
        """
        :param Sequence[_builtins.str] days: List of days on which schedule need to be active. Valid values are SUN, MON, TUE, WED, THU, FRI and SAT.
        :param _builtins.str time_zone: Time zone in which the schedule needs to be executed. Example Valid values: UTC, America/New*York, Europe/London, Asia/Kolkata, Asia/Tokyo, Asia/Hong*Kong, Asia/Singapore, Australia/Melbourne and Australia/Sydney.
        :param _builtins.str end_time: End time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        :param _builtins.str start_time: Start time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        """
        pulumi.set(__self__, "days", days)
        pulumi.set(__self__, "time_zone", time_zone)
        if all_day is not None:
            pulumi.set(__self__, "all_day", all_day)
        if end_time is not None:
            pulumi.set(__self__, "end_time", end_time)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)

    @_builtins.property
    @pulumi.getter
    def days(self) -> Sequence[_builtins.str]:
        """
        List of days on which schedule need to be active. Valid values are SUN, MON, TUE, WED, THU, FRI and SAT.
        """
        return pulumi.get(self, "days")

    @_builtins.property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> _builtins.str:
        """
        Time zone in which the schedule needs to be executed. Example Valid values: UTC, America/New*York, Europe/London, Asia/Kolkata, Asia/Tokyo, Asia/Hong*Kong, Asia/Singapore, Australia/Melbourne and Australia/Sydney.
        """
        return pulumi.get(self, "time_zone")

    @_builtins.property
    @pulumi.getter(name="allDay")
    def all_day(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "all_day")

    @_builtins.property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[_builtins.str]:
        """
        End time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        """
        return pulumi.get(self, "end_time")

    @_builtins.property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[_builtins.str]:
        """
        Start time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        """
        return pulumi.get(self, "start_time")


@pulumi.output_type
class GetOrchestratorConfigBinpackingResult(dict):
    def __init__(__self__, *,
                 disruption: Optional['outputs.GetOrchestratorConfigBinpackingDisruptionResult'] = None,
                 pod_eviction: Optional['outputs.GetOrchestratorConfigBinpackingPodEvictionResult'] = None):
        """
        :param 'GetOrchestratorConfigBinpackingDisruptionArgs' disruption: Harness disruption configuration
        :param 'GetOrchestratorConfigBinpackingPodEvictionArgs' pod_eviction: Harness Pod Evictor Configuration
        """
        if disruption is not None:
            pulumi.set(__self__, "disruption", disruption)
        if pod_eviction is not None:
            pulumi.set(__self__, "pod_eviction", pod_eviction)

    @_builtins.property
    @pulumi.getter
    def disruption(self) -> Optional['outputs.GetOrchestratorConfigBinpackingDisruptionResult']:
        """
        Harness disruption configuration
        """
        return pulumi.get(self, "disruption")

    @_builtins.property
    @pulumi.getter(name="podEviction")
    def pod_eviction(self) -> Optional['outputs.GetOrchestratorConfigBinpackingPodEvictionResult']:
        """
        Harness Pod Evictor Configuration
        """
        return pulumi.get(self, "pod_eviction")


@pulumi.output_type
class GetOrchestratorConfigBinpackingDisruptionResult(dict):
    def __init__(__self__, *,
                 budgets: Optional[Sequence['outputs.GetOrchestratorConfigBinpackingDisruptionBudgetResult']] = None,
                 criteria: Optional[_builtins.str] = None,
                 delay: Optional[_builtins.str] = None):
        """
        :param Sequence['GetOrchestratorConfigBinpackingDisruptionBudgetArgs'] budgets: Budgets for disruption
        :param _builtins.str criteria: Criteria for considering a nodes for disruption
        :param _builtins.str delay: Deletion delay
        """
        if budgets is not None:
            pulumi.set(__self__, "budgets", budgets)
        if criteria is not None:
            pulumi.set(__self__, "criteria", criteria)
        if delay is not None:
            pulumi.set(__self__, "delay", delay)

    @_builtins.property
    @pulumi.getter
    def budgets(self) -> Optional[Sequence['outputs.GetOrchestratorConfigBinpackingDisruptionBudgetResult']]:
        """
        Budgets for disruption
        """
        return pulumi.get(self, "budgets")

    @_builtins.property
    @pulumi.getter
    def criteria(self) -> Optional[_builtins.str]:
        """
        Criteria for considering a nodes for disruption
        """
        return pulumi.get(self, "criteria")

    @_builtins.property
    @pulumi.getter
    def delay(self) -> Optional[_builtins.str]:
        """
        Deletion delay
        """
        return pulumi.get(self, "delay")


@pulumi.output_type
class GetOrchestratorConfigBinpackingDisruptionBudgetResult(dict):
    def __init__(__self__, *,
                 nodes: _builtins.str,
                 reasons: Optional[Sequence[_builtins.str]] = None,
                 schedule: Optional['outputs.GetOrchestratorConfigBinpackingDisruptionBudgetScheduleResult'] = None):
        """
        :param _builtins.str nodes: Number or percentage of Nodes to consider for disruption
        :param Sequence[_builtins.str] reasons: Reasons for disruption
        :param 'GetOrchestratorConfigBinpackingDisruptionBudgetScheduleArgs' schedule: Schedule for disruption budget
        """
        pulumi.set(__self__, "nodes", nodes)
        if reasons is not None:
            pulumi.set(__self__, "reasons", reasons)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)

    @_builtins.property
    @pulumi.getter
    def nodes(self) -> _builtins.str:
        """
        Number or percentage of Nodes to consider for disruption
        """
        return pulumi.get(self, "nodes")

    @_builtins.property
    @pulumi.getter
    def reasons(self) -> Optional[Sequence[_builtins.str]]:
        """
        Reasons for disruption
        """
        return pulumi.get(self, "reasons")

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> Optional['outputs.GetOrchestratorConfigBinpackingDisruptionBudgetScheduleResult']:
        """
        Schedule for disruption budget
        """
        return pulumi.get(self, "schedule")


@pulumi.output_type
class GetOrchestratorConfigBinpackingDisruptionBudgetScheduleResult(dict):
    def __init__(__self__, *,
                 duration: _builtins.str,
                 frequency: _builtins.str):
        """
        :param _builtins.str duration: Duration for disruption budget
        :param _builtins.str frequency: Frequency for disruption budget
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "frequency", frequency)

    @_builtins.property
    @pulumi.getter
    def duration(self) -> _builtins.str:
        """
        Duration for disruption budget
        """
        return pulumi.get(self, "duration")

    @_builtins.property
    @pulumi.getter
    def frequency(self) -> _builtins.str:
        """
        Frequency for disruption budget
        """
        return pulumi.get(self, "frequency")


@pulumi.output_type
class GetOrchestratorConfigBinpackingPodEvictionResult(dict):
    def __init__(__self__, *,
                 threshold: 'outputs.GetOrchestratorConfigBinpackingPodEvictionThresholdResult'):
        """
        :param 'GetOrchestratorConfigBinpackingPodEvictionThresholdArgs' threshold: Minimum Threshold for considering a node as underutilized
        """
        pulumi.set(__self__, "threshold", threshold)

    @_builtins.property
    @pulumi.getter
    def threshold(self) -> 'outputs.GetOrchestratorConfigBinpackingPodEvictionThresholdResult':
        """
        Minimum Threshold for considering a node as underutilized
        """
        return pulumi.get(self, "threshold")


@pulumi.output_type
class GetOrchestratorConfigBinpackingPodEvictionThresholdResult(dict):
    def __init__(__self__, *,
                 cpu: _builtins.float,
                 memory: _builtins.float):
        """
        :param _builtins.float cpu: CPU percentage for considering a node as underutilized
        :param _builtins.float memory: Memory percentage for considering a node as underutilized
        """
        pulumi.set(__self__, "cpu", cpu)
        pulumi.set(__self__, "memory", memory)

    @_builtins.property
    @pulumi.getter
    def cpu(self) -> _builtins.float:
        """
        CPU percentage for considering a node as underutilized
        """
        return pulumi.get(self, "cpu")

    @_builtins.property
    @pulumi.getter
    def memory(self) -> _builtins.float:
        """
        Memory percentage for considering a node as underutilized
        """
        return pulumi.get(self, "memory")


@pulumi.output_type
class GetOrchestratorConfigCommitmentIntegrationResult(dict):
    def __init__(__self__, *,
                 enabled: _builtins.bool,
                 master_account_id: _builtins.str):
        """
        :param _builtins.bool enabled: Flag to enable Commitment Integration
        :param _builtins.str master_account_id: Master AWS account id for commitment integration
        """
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "master_account_id", master_account_id)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> _builtins.bool:
        """
        Flag to enable Commitment Integration
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="masterAccountId")
    def master_account_id(self) -> _builtins.str:
        """
        Master AWS account id for commitment integration
        """
        return pulumi.get(self, "master_account_id")


@pulumi.output_type
class GetOrchestratorConfigDistributionResult(dict):
    def __init__(__self__, *,
                 ondemand_replica_percentage: _builtins.float,
                 base_ondemand_capacity: Optional[_builtins.int] = None,
                 selector: Optional[_builtins.str] = None,
                 strategy: Optional[_builtins.str] = None):
        """
        :param _builtins.float ondemand_replica_percentage: Percentage of on-demand replicas required for workloads
        :param _builtins.int base_ondemand_capacity: Number of minimum ondemand replicas required for workloads
        :param _builtins.str selector: Selector for choosing workloads for distribution
        :param _builtins.str strategy: Strategy for choosing spot nodes for cluster
        """
        pulumi.set(__self__, "ondemand_replica_percentage", ondemand_replica_percentage)
        if base_ondemand_capacity is not None:
            pulumi.set(__self__, "base_ondemand_capacity", base_ondemand_capacity)
        if selector is not None:
            pulumi.set(__self__, "selector", selector)
        if strategy is not None:
            pulumi.set(__self__, "strategy", strategy)

    @_builtins.property
    @pulumi.getter(name="ondemandReplicaPercentage")
    def ondemand_replica_percentage(self) -> _builtins.float:
        """
        Percentage of on-demand replicas required for workloads
        """
        return pulumi.get(self, "ondemand_replica_percentage")

    @_builtins.property
    @pulumi.getter(name="baseOndemandCapacity")
    def base_ondemand_capacity(self) -> Optional[_builtins.int]:
        """
        Number of minimum ondemand replicas required for workloads
        """
        return pulumi.get(self, "base_ondemand_capacity")

    @_builtins.property
    @pulumi.getter
    def selector(self) -> Optional[_builtins.str]:
        """
        Selector for choosing workloads for distribution
        """
        return pulumi.get(self, "selector")

    @_builtins.property
    @pulumi.getter
    def strategy(self) -> Optional[_builtins.str]:
        """
        Strategy for choosing spot nodes for cluster
        """
        return pulumi.get(self, "strategy")


@pulumi.output_type
class GetOrchestratorConfigNodePreferencesResult(dict):
    def __init__(__self__, *,
                 reverse_fallback_interval: Optional[_builtins.str] = None,
                 ttl: Optional[_builtins.str] = None):
        """
        :param _builtins.str reverse_fallback_interval: Reverse fallback interval
        :param _builtins.str ttl: TTL for nodes
        """
        if reverse_fallback_interval is not None:
            pulumi.set(__self__, "reverse_fallback_interval", reverse_fallback_interval)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)

    @_builtins.property
    @pulumi.getter(name="reverseFallbackInterval")
    def reverse_fallback_interval(self) -> Optional[_builtins.str]:
        """
        Reverse fallback interval
        """
        return pulumi.get(self, "reverse_fallback_interval")

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> Optional[_builtins.str]:
        """
        TTL for nodes
        """
        return pulumi.get(self, "ttl")


@pulumi.output_type
class GetOrchestratorConfigReplacementScheduleResult(dict):
    def __init__(__self__, *,
                 applies_to: 'outputs.GetOrchestratorConfigReplacementScheduleAppliesToResult',
                 window_type: _builtins.str,
                 window_details: Optional['outputs.GetOrchestratorConfigReplacementScheduleWindowDetailsResult'] = None):
        """
        :param 'GetOrchestratorConfigReplacementScheduleAppliesToArgs' applies_to: Defines the scope of the replacement schedule
        :param _builtins.str window_type: Window type for replacement schedule
        """
        pulumi.set(__self__, "applies_to", applies_to)
        pulumi.set(__self__, "window_type", window_type)
        if window_details is not None:
            pulumi.set(__self__, "window_details", window_details)

    @_builtins.property
    @pulumi.getter(name="appliesTo")
    def applies_to(self) -> 'outputs.GetOrchestratorConfigReplacementScheduleAppliesToResult':
        """
        Defines the scope of the replacement schedule
        """
        return pulumi.get(self, "applies_to")

    @_builtins.property
    @pulumi.getter(name="windowType")
    def window_type(self) -> _builtins.str:
        """
        Window type for replacement schedule
        """
        return pulumi.get(self, "window_type")

    @_builtins.property
    @pulumi.getter(name="windowDetails")
    def window_details(self) -> Optional['outputs.GetOrchestratorConfigReplacementScheduleWindowDetailsResult']:
        return pulumi.get(self, "window_details")


@pulumi.output_type
class GetOrchestratorConfigReplacementScheduleAppliesToResult(dict):
    def __init__(__self__, *,
                 consolidation: _builtins.bool,
                 harness_pod_eviction: _builtins.bool,
                 reverse_fallback: _builtins.bool):
        pulumi.set(__self__, "consolidation", consolidation)
        pulumi.set(__self__, "harness_pod_eviction", harness_pod_eviction)
        pulumi.set(__self__, "reverse_fallback", reverse_fallback)

    @_builtins.property
    @pulumi.getter
    def consolidation(self) -> _builtins.bool:
        return pulumi.get(self, "consolidation")

    @_builtins.property
    @pulumi.getter(name="harnessPodEviction")
    def harness_pod_eviction(self) -> _builtins.bool:
        return pulumi.get(self, "harness_pod_eviction")

    @_builtins.property
    @pulumi.getter(name="reverseFallback")
    def reverse_fallback(self) -> _builtins.bool:
        return pulumi.get(self, "reverse_fallback")


@pulumi.output_type
class GetOrchestratorConfigReplacementScheduleWindowDetailsResult(dict):
    def __init__(__self__, *,
                 days: Sequence[_builtins.str],
                 time_zone: _builtins.str,
                 all_day: Optional[_builtins.bool] = None,
                 end_time: Optional[_builtins.str] = None,
                 start_time: Optional[_builtins.str] = None):
        """
        :param Sequence[_builtins.str] days: List of days on which schedule need to be active. Valid values are SUN, MON, TUE, WED, THU, FRI and SAT.
        :param _builtins.str time_zone: Time zone in which the schedule needs to be executed. Example Valid values: UTC, America/New*York, Europe/London, Asia/Kolkata, Asia/Tokyo, Asia/Hong*Kong, Asia/Singapore, Australia/Melbourne and Australia/Sydney.
        :param _builtins.str end_time: End time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        :param _builtins.str start_time: Start time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        """
        pulumi.set(__self__, "days", days)
        pulumi.set(__self__, "time_zone", time_zone)
        if all_day is not None:
            pulumi.set(__self__, "all_day", all_day)
        if end_time is not None:
            pulumi.set(__self__, "end_time", end_time)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)

    @_builtins.property
    @pulumi.getter
    def days(self) -> Sequence[_builtins.str]:
        """
        List of days on which schedule need to be active. Valid values are SUN, MON, TUE, WED, THU, FRI and SAT.
        """
        return pulumi.get(self, "days")

    @_builtins.property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> _builtins.str:
        """
        Time zone in which the schedule needs to be executed. Example Valid values: UTC, America/New*York, Europe/London, Asia/Kolkata, Asia/Tokyo, Asia/Hong*Kong, Asia/Singapore, Australia/Melbourne and Australia/Sydney.
        """
        return pulumi.get(self, "time_zone")

    @_builtins.property
    @pulumi.getter(name="allDay")
    def all_day(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "all_day")

    @_builtins.property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[_builtins.str]:
        """
        End time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        """
        return pulumi.get(self, "end_time")

    @_builtins.property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[_builtins.str]:
        """
        Start time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        """
        return pulumi.get(self, "start_time")


